# atom

[![GitHub issues](https://img.shields.io/github/issues/xinetzone/atom)](https://github.com/xinetzone/atom/issues) [![GitHub forks](https://img.shields.io/github/forks/xinetzone/atom)](https://github.com/xinetzone/atom/network) [![GitHub stars](https://img.shields.io/github/stars/xinetzone/atom)](https://github.com/xinetzone/atom/stargazers) [![GitHub license](https://img.shields.io/github/license/xinetzone/atom)](https://github.com/xinetzone/atom/blob/main/LICENSE)  ![repo size](https://img.shields.io/github/repo-size/xinetzone/atom.svg) [![contributors](https://img.shields.io/github/contributors/xinetzone/atom.svg)](https://github.com/xinetzone/atom/graphs/contributors) [![watcher](https://img.shields.io/github/watchers/xinetzone/atom.svg)](https://github.com/xinetzone/atom/watchers)

Discover and create anything interesting!

混合 MXNet，PyTorch，TensrFlow 的库。

## PyPI

Provide PyPI support.

```sh
pip install xint
```

## Help

View [xint](https://xinetzone.github.io/dao/categories/xint/) in GitHub.